spglib
======

Python bindings for C library for finding and handling crystal
symmetries

Installation
------------

The package is developed on github. You can get the source for the
released versions from the
`repository <https://github.com/spglib/spglib/releases>`__.

Using package distribution service
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

The easiest way to install python-spglib is to use the pypi package, for
which numpy is required to be installed before the installation. A
command to install spglib is:

::

    pip install spglib

Conda is another choice:

::

    conda install -c conda-forge spglib

These packages are made by Pawel T. Jochym.
